==> opp-chub-1.0.5.tar.gz: opp-chub-1.0.5/setup.py <==
# -*- coding: utf-8 -*-
# Copyright 2016 Open Permissions Platform Coalition
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License. You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software distributed under the License is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and limitations under the License.
# 

from setuptools import setup
import re

with open('chub/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

setup(name='opp-chub',
      version=version,
      description='Asynchronous Python client for the Open Permissions Platform Coalition REST Services',
      author='Open Permissions Platform Coalition',
      author_email='support-copyrighthub@cde.catapult.org.uk',
      url='https://github.com/openpermissions/chub',
      packages=['chub'],
      install_requires=['tornado'],
      license='Apache 2.0',
      classifiers=(
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'Natural Language :: English',
            'License :: OSI Approved :: Apache Software License',
            'Programming Language :: Python',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: Implementation :: CPython',
      ),
      include_package_data=True,
      package_data={
            '': [ 'LICENSE' ]
      }
      )

==> opp-chub-1.0.6.tar.gz: opp-chub-1.0.6/setup.py <==
# -*- coding: utf-8 -*-
# Copyright 2016 Open Permissions Platform Coalition
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License. You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software distributed under the License is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and limitations under the License.
#

from setuptools import setup
import re

with open('chub/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

setup(name='opp-chub',
      version=version,
      description='Asynchronous Python client for the Open Permissions Platform Coalition REST Services',
      author='Open Permissions Platform Coalition',
      author_email='support@openpermissions.org',
      url='https://github.com/openpermissions/chub',
      packages=['chub'],
      install_requires=['tornado'],
      license='Apache 2.0',
      classifiers=(
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'Natural Language :: English',
            'License :: OSI Approved :: Apache Software License',
            'Programming Language :: Python',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: Implementation :: CPython',
      ),
      include_package_data=True,
      package_data={
            '': [ 'LICENSE' ]
      }
      )
